:mod:`exspy.utils.eels`
-----------------------

.. currentmodule:: exspy.utils.eels


.. autosummary::
   effective_angle
   get_edges_near_energy
   get_info_from_edges
   iMFP_angular_correction
   iMFP_Iakoubovskii
   iMFP_TPP2M


.. automodule:: exspy.utils.eels
   :members:
